# time

run and time the ls command

    /usr/bin/time ls


run foo.py and print time and usage statistics

    /usr/bin/time -l foo.py



# Basic Usage

Run and time a command:

    /usr/bin/time <command>


`time` is a Unix command, but is also the name of a built-in function in many
shells. These examples use the full path `/usr/bin/time` to avoid collisions
with shell functionality, which can differ in confusing ways.


